#!/bin/sh
#-------------------------------------------------------------------------------
# /opt/files/usr/local/bin/faxprint.sh - Druck von gzippten sff-Dateien
#
# Creation: 30.10.2002  Initialversion                                VER: 0.1
#           04.11.2002  Doku- und Kommentarnderungen
#                       Debugoptionen implementiert                   VER: 0.2
#           08.11.2002  Druckpositionierung implementiert             VER: 0.4
#           10.11.2002  absolute Pfade fr die .ps Dateien            VER: 0.5
#           30.05.2003  rem $1.prn im -t Abschnitt eingefgt          VER: 0.7
#           29.09.2004  Kompletter Neuaufbau fr fli4l Version 2.1.8  VER: 0.8
#           27.10.2004  Bugfix                                        VER: 0.81
#           19.07.2005  Anpassung fr fli4l Version 2.1.10/2.1.11     VER: 0.9
#           01.08.2005  Neue sff2misc-Version                         VER: 0.91
#           03.09.2005  Debugging mit FAXPRINT_DEBUG='yes', sff2misc  VER: 0.92
#-------------------------------------------------------------------------------
# falscher Aufruf
if [ "$1" = "" ] || [ "$1" = "-h" ]  || [ "$1" = "-?" ]
then
    echo "usage $0 [filename | -h ]"
    echo "      -h = help"
    exit 0
fi

# Variablen lesen
. /boot/rc.cfg

faxprint_logfile=/var/log/log.faxprint
curr_date=`date +%d.%m.%Y-%H:%M:%S:`

if [ -f /usr/bin/logger ]
then
    msgcmd="/usr/bin/logger -t faxprint -p local0"
    msgcmdfail="$msgcmd.error "
    msgcmdinfo="$msgcmd.info "
else
    msgcmd="echo "
    msgcmdfail="echo "
    msgcmdinfo="echo "
fi

faxprint_rmcommand ()
{
  rm -f /tmp/$FILENAME.sff
  rm -f /tmp/$FILENAME.prn
  rm -f /tmp/$FILENAME.ps
}

do_msgcmdinfo ()
{
  echo "$message" >> $faxprint_logfile
  $msgcmdinfo "$message"
}

do_msgcmdfail ()
{
  echo "$message" >> $faxprint_logfile
  $msgcmdfail "$message"
}

if [ "$FAXPRINT_DEBUG" = "yes" ]
then
    message="$curr_date starting faxprint.sh with file $1"
    echo "$message" > $faxprint_logfile
    $msgcmdinfo "$message"
fi

# Dateiname ohne Suffix
FILENAME=`basename $1 | sed -e 's/\.sff\.gz//'`

if [ "$FAXPRINT_DEBUG" = "yes" ]
then
    message="$curr_date file without suffix is $FILENAME"
    do_msgcmdinfo
fi

# entpacken
if [ "$FAXPRINT_DEBUG" = "yes" ]
then
    message="$curr_date unpacking $FILENAME.sff.gz to /tmp/$FILENAME.sff"
    do_msgcmdinfo
fi

cat $FILENAME.sff.gz | gzip -d >/tmp/$FILENAME.sff
retval=$?

if [ "$retval" = 0 ]
then
    if [ "$FAXPRINT_DEBUG" = "yes" ]
    then
        message="$curr_date $FILENAME.sff.gz successfull unpacked to /tmp/$FILENAME.sff"
        do_msgcmdinfo
    fi
else
    if [ "$FAXPRINT_DEBUG" = "yes" ]
    then
        message="$curr_date cannot unpack $FILENAME.sff.gz to /tmp/$FILENAME.sff"
        do_msgcmdfail
    fi
        
    faxprint_rmcommand
    exit 1
fi

# Umwandlung von sff zu Postscript
if [ "$FAXPRINT_DEBUG" = "yes" ]
then
    message="$curr_date converting /tmp/$FILENAME.sff to /tmp/$FILENAME.ps"
    do_msgcmdinfo
fi

/usr/local/bin/sff2misc -p /tmp/$FILENAME.sff /tmp/$FILENAME
retval=$?

if [ "$retval" = 0 ]
then
    if [ "$FAXPRINT_DEBUG" = "yes" ]
    then
        message="$curr_date /tmp/$FILENAME.sff successfull converted to /tmp/$FILENAME.ps"
        do_msgcmdinfo
    fi
else
    if [ "$FAXPRINT_DEBUG" = "yes" ]
    then
        message="$curr_date cannot convert /tmp/$FILENAME.sff to /tmp/$FILENAME.ps"
        do_msgcmdfail
    fi
fi

# Umwandlung von Postscript zu PDF
if [ "$FAXPRINT_MAKE_PDF" = "yes" ]
then
    if [ "$FAXPRINT_DEBUG" = "yes" ]
    then
        message="$curr_date converting /tmp/$FILENAME.ps to /tmp/$FILENAME.pdf"
        do_msgcmdinfo

        /usr/local/bin/gs -q                 \
        -sDEVICE=pdfwrite                    \
        -sOutputFile=/data/fax/$FILENAME.pdf \
        -dBATCH -dNOPAUSE                    \
        /opt/files/usr/local/bin/margins.ps  \
        /tmp/$FILENAME.ps                    \
        >> $faxprint_logfile 2>&1
        retval=$?
    else
        /usr/local/bin/gs -q                 \
        -sDEVICE=pdfwrite                    \
        -sOutputFile=/data/fax/$FILENAME.pdf \
        -dBATCH -dNOPAUSE                    \
        /opt/files/usr/local/bin/margins.ps  \
        /tmp/$FILENAME.ps
        retval=$?
    fi

    if [ "$retval" = 0 ]
    then
        if [ "$FAXPRINT_DEBUG" = "yes" ]
        then
            message="$curr_date /tmp/$FILENAME.ps successfull converted to /tmp/$FILENAME.pdf"
            do_msgcmdinfo
        fi
    else
        if [ "$FAXPRINT_DEBUG" = "yes" ]
        then
            message="$curr_date cannot convert /tmp/$FILENAME.ps to /tmp/$FILENAME.pdf"
            do_msgcmdfail
        fi
        
        faxprint_rmcommand
        exit 1
    fi
fi

# Umwandlung in Druckersprache
if [ "$FAXPRINT_DEBUG" = "yes" ]
then
    message="$curr_date converting /tmp/$FILENAME.ps to /tmp/$FILENAME.prn"
    do_msgcmdinfo

    /usr/local/bin/gs -q                \
    -sDEVICE=$FAXPRINT_PRINTER_TYP      \
    -sOutputFile=/tmp/$FILENAME.prn     \
    -dBATCH -dNOPAUSE                   \
    /opt/files/usr/local/bin/margins.ps \
    /tmp/$FILENAME.ps                   \
    >> $faxprint_logfile 2>&1
    retval=$?
else
    /usr/local/bin/gs -q                \
    -sDEVICE=$FAXPRINT_PRINTER_TYP      \
    -sOutputFile=/tmp/$FILENAME.prn     \
    -dBATCH -dNOPAUSE                   \
    /opt/files/usr/local/bin/margins.ps \
    /tmp/$FILENAME.ps
    retval=$?
fi

if [ "$retval" = 0 ]
then
    if [ "$FAXPRINT_DEBUG" = "yes" ]
    then
        message="$curr_date /tmp/$FILENAME.ps successfull converted to /tmp/$FILENAME.prn"
        do_msgcmdinfo
    fi
else
    if [ "$FAXPRINT_DEBUG" = "yes" ]
    then
        message="$curr_date cannot convert /tmp/$FILENAME.ps to /tmp/$FILENAME.prn"
        do_msgcmdfail
    fi

    faxprint_rmcommand
    exit 1
fi

# Drucken
if [ "$FAXPRINT_DEBUG" = "yes" ]
then
    message="$curr_date printing /tmp/$FILENAME.prn on $FAXPRINT_PRINTER_QUEUE"
    do_msgcmdinfo

    /usr/bin/lpr -P$FAXPRINT_PRINTER_QUEUE /tmp/$FILENAME.prn >> $faxprint_logfile 2>&1
    retval=$?
else
    /usr/bin/lpr -P$FAXPRINT_PRINTER_QUEUE /tmp/$FILENAME.prn
    retval=$?
fi

if [ "$retval" = 0 ]
then
    if [ "$FAXPRINT_DEBUG" = "yes" ]
    then
        message="$curr_date /tmp/$FILENAME.prn successfull printed on $FAXPRINT_PRINTER_QUEUE"
        do_msgcmdinfo
    fi
else
    if [ "$FAXPRINT_DEBUG" = "yes" ]
    then
        message="$curr_date cannot print /tmp/$FILENAME.prn on $FAXPRINT_PRINTER_QUEUE"
        do_msgcmdfail
    fi
    
    faxprint_rmcommand
    exit 1
fi

# Muell aufraeumen
faxprint_rmcommand
exit 0
